/* Generated by Nim Compiler v1.6.14 */
#define NIM_INTBITS 32
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <setjmp.h>
#include <stdio.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
#define nimfr_(x, y)
#define nimln_(x, y)
typedef struct NimStringDesc NimStringDesc;
typedef struct TGenericSeq TGenericSeq;
typedef struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g;
typedef struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ;
typedef struct tySequence__CZrkID0OnHjQpN63AqYJwg tySequence__CZrkID0OnHjQpN63AqYJwg;
typedef struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw tySequence__qIo1GWQhO9cOgsAJDKUY8kw;
typedef struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ;
typedef struct TNimType TNimType;
typedef struct TNimNode TNimNode;
typedef struct tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw;
typedef struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA;
typedef struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__QbmGqFaLnb1IWWToREeaIA tySequence__QbmGqFaLnb1IWWToREeaIA;
typedef struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g;
typedef struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA tyObject_CellSeq__nav876ELHgxScHhs30CKiA;
typedef struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ;
typedef struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ;
typedef struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ;
typedef struct tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw;
typedef struct tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA;
typedef struct tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA;
typedef struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A;
typedef struct tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg;
typedef struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw;
typedef struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw;
typedef struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA;
typedef struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg;
typedef struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA;
typedef struct tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ;
typedef struct tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ;
typedef struct tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA;
typedef struct tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA;
typedef struct tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg;
typedef struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA;
typedef struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA;
typedef struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw tySequence__QAzA9aOtpCCvcxe8jjx2Rmw;
typedef struct TSafePoint TSafePoint;
typedef struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw;
typedef struct tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tyObject_Table__IARuioJxsgUIwpXiUkOgKg tyObject_Table__IARuioJxsgUIwpXiUkOgKg;
typedef struct tySequence__SFipDZIkFtPcrLs0AGBBjQ tySequence__SFipDZIkFtPcrLs0AGBBjQ;
typedef struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg tyTuple__8ZxhPt1NwfElsJs8zUSV9bg;
typedef struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA;
typedef struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA;
struct TGenericSeq {
NI len;
NI reserved;
};
struct NimStringDesc {
  TGenericSeq Sup;
NIM_CHAR data[SEQ_DECL_SIZE];
};
typedef NU8 tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
struct tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ {
tySequence__CZrkID0OnHjQpN63AqYJwg* data;
NI counter;
NI first;
NI last;
};
struct tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g {
NIM_BOOL isUnquoted;
tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A kind;
union{
struct {NimStringDesc* str;
} _kind_1;
struct {NI64 num;
} _kind_2;
struct {NF fnum;
} _kind_3;
struct {NIM_BOOL bval;
} _kind_4;
struct {tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ fields;
} _kind_6;
struct {tySequence__qIo1GWQhO9cOgsAJDKUY8kw* elems;
} _kind_7;
};
};
struct tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ {
NI Field0;
NI Field1;
NimStringDesc* Field2;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field3;
};
typedef NU8 tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ;
typedef NU8 tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w;
typedef N_NIMCALL_PTR(void, tyProc__ojoeKfW4VYIm36I9cpDTQIg) (void* p, NI op);
typedef N_NIMCALL_PTR(void*, tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ) (void* p);
struct TNimType {
NI size;
NI align;
tyEnum_TNimKind__pspQAsqJLrw3jEKBD9bxmyQ kind;
tySet_tyEnum_TNimTypeFlag__Yt5hq6z2IoHhKZrzIVrc1w flags;
TNimType* base;
TNimNode* node;
void* finalizer;
tyProc__ojoeKfW4VYIm36I9cpDTQIg marker;
tyProc__WSm2xU5ARYv9aAR4l0z9c9auQ deepcopy;
};
struct RootObj {
TNimType* m_type;
};
struct Exception {
  RootObj Sup;
Exception* parent;
NCSTRING name;
NimStringDesc* message;
tySequence__QbmGqFaLnb1IWWToREeaIA* trace;
Exception* up;
};
struct tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ {
  Exception Sup;
};
struct tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
struct tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NU8 tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw;
struct TNimNode {
tyEnum_TNimNodeKind__rrp49bl1h9aEkXfXp9bNg0yZw kind;
NI offset;
TNimType* typ;
NCSTRING name;
NI len;
TNimNode** sons;
};
struct tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g {
NI refcount;
TNimType* typ;
};
struct tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ {
void* bottom;
};
struct tyObject_CellSeq__nav876ELHgxScHhs30CKiA {
NI len;
NI cap;
tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g** d;
};
typedef tyObject_SmallChunk__eUrTKmsk1Dqt5tm2WUT2Lw* tyArray__1eFxjkcKGHnofywkmCV8oQ[256];
typedef NU32 tyArray__BHbOSqU1t9b3Gt7K2c6fQig[24];
typedef tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* tyArray__KxTmKT9a3kTkdwYfqXhEYSw[32];
typedef tyArray__KxTmKT9a3kTkdwYfqXhEYSw tyArray__ATT5LBefmjy9bg8ApRmg3rw[24];
typedef tyObject_Trunk__Ju1AURWHenTn3cJwAjbUhg* tyArray__RxhBwkGQwTHLKhoK685Xfg[256];
struct tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A {
tyArray__RxhBwkGQwTHLKhoK685Xfg data;
};
typedef tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* tyArray__DrxDrI9bg9apB70ydOoNZrWw[2];
struct tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw {
tyArray__DrxDrI9bg9apB70ydOoNZrWw link;
NI key;
NI upperBound;
NI level;
};
struct tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA {
tyObject_BigChunk__39bC3HTk2w4NGDjG74oNjmA* Field0;
NI Field1;
};
typedef tyTuple__p2vAp9cQ6YrpDq9cI3XzEDWA tyArray__wsokuoa9bVBSU4gPLKbFaaw[30];
struct tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw {
NI len;
tyArray__wsokuoa9bVBSU4gPLKbFaaw chunks;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw* next;
};
struct tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ {
NI minLargeObj;
NI maxLargeObj;
tyArray__1eFxjkcKGHnofywkmCV8oQ freeSmallChunks;
NU32 flBitmap;
tyArray__BHbOSqU1t9b3Gt7K2c6fQig slBitmap;
tyArray__ATT5LBefmjy9bg8ApRmg3rw matrix;
tyObject_LLChunk__Fjkr5Ya6Zl0UoUGxG047hA* llmem;
NI currMem;
NI maxMem;
NI freeMem;
NI occ;
NI lastSize;
tyObject_IntSet__WrQriiGmHk59cB1lNPtGo6A chunkStarts;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* root;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* deleted;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* last;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw* freeAvlNodes;
NIM_BOOL locked;
NIM_BOOL blockChunkSizeIncrease;
NI nextChunkSize;
tyObject_AvlNode__aGkK1t9a0WoXjpugXR6FWpw bottomData;
tyObject_HeapLinks__5IkCDh5QlsYpsfEMJf6zNw heapLinks;
};
struct tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg {
NI stackScans;
NI cycleCollections;
NI maxThreshold;
NI maxStackSize;
NI maxStackCells;
NI cycleTableSize;
NI64 maxPause;
};
struct tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA {
NI counter;
NI max;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ* head;
tyObject_PageDesc__N7tjEodqPVJaQ6oKQW8YfQ** data;
};
struct tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ {
tyObject_GcStack__qFeGMKlnq6c9cTM2vPWycQQ stack;
NI cycleThreshold;
NI zctThreshold;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA zct;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA decStack;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA tempStack;
NI recGcLock;
tyObject_MemRegion__6QRscFDo4mEwbg9aL76vDGQ region;
tyObject_GcStat__OG9ams3mtFJyICkjTOHbc9bg stat;
tyObject_CellSet__A0mJvGLunfUxGkLUtesjdA marked;
tyObject_CellSeq__nav876ELHgxScHhs30CKiA additionalRoots;
NI gcThreadId;
};
typedef NimStringDesc* tyArray__24KAM9afIUgUaqBaEBB6r9bg[3];
typedef NU8 tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A;
struct tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ {
  tyObject_ValueError__5lcTdgqMq62cNGRwBb0thA Sup;
};
typedef NU8 tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w;
struct tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA {
  tyObject_CatchableError__8K3kdpxrBD9aI27J0kpSCpQ Sup;
};
typedef NU8 tySet_tyChar__nmiMWKVIe46vacnhAFrQvw[32];
struct tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA {
  RootObj Sup;
NI bufpos;
NimStringDesc* buf;
tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input;
NI lineNumber;
NI sentinel;
NI lineStart;
NI offsetBase;
tySet_tyChar__nmiMWKVIe46vacnhAFrQvw refillChars;
};
typedef NU8 tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg;
typedef NU8 tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg;
typedef NU8 tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w;
struct tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA {
  tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA Sup;
NimStringDesc* a;
tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tok;
tyEnum_JsonEventKind__eElE9akd9bXwK3AkFXF85u9bg kind;
tyEnum_JsonError__9bOLqlKJO6K9b1fxRo9bWfh3w err;
tySequence__QAzA9aOtpCCvcxe8jjx2Rmw* state;
NimStringDesc* filename;
NIM_BOOL rawStringLiterals;
};
struct TSafePoint {
TSafePoint* prev;
NI status;
jmp_buf context;
};
typedef N_NIMCALL_PTR(void, tyProc__u1QtPTYUJu1ozpzb9a8xchw) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__VytW5cBLp1DOuwAj9cjoj3Q) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(void, tyProc__nAUmmvz53fMDhkU9aQ4i60Q) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NI pos);
typedef N_NIMCALL_PTR(NI, tyProc__rvgAWCz6iG9cntloh2xzZmQ) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s);
typedef N_NIMCALL_PTR(NI, tyProc__sAr4e3JGOuIBVEZ29aGGKUQ) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc** buffer, tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw slice);
typedef N_NIMCALL_PTR(NIM_BOOL, tyProc__7SoiV5lfjKUldz1ENKXq1w) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc** line);
typedef N_NIMCALL_PTR(NI, tyProc__mPF9ae7sAGGCOezlsIuH6Yg) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, void* buffer, NI bufLen);
typedef N_NIMCALL_PTR(void, tyProc__1nrRaSRiXjiE9bnEpZhmOsA) (tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, void* buffer, NI bufLen);
struct tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg {
  RootObj Sup;
tyProc__u1QtPTYUJu1ozpzb9a8xchw closeImpl;
tyProc__VytW5cBLp1DOuwAj9cjoj3Q atEndImpl;
tyProc__nAUmmvz53fMDhkU9aQ4i60Q setPositionImpl;
tyProc__rvgAWCz6iG9cntloh2xzZmQ getPositionImpl;
tyProc__sAr4e3JGOuIBVEZ29aGGKUQ readDataStrImpl;
tyProc__7SoiV5lfjKUldz1ENKXq1w readLineImpl;
tyProc__mPF9ae7sAGGCOezlsIuH6Yg readDataImpl;
tyProc__mPF9ae7sAGGCOezlsIuH6Yg peekDataImpl;
tyProc__1nrRaSRiXjiE9bnEpZhmOsA writeDataImpl;
tyProc__u1QtPTYUJu1ozpzb9a8xchw flushImpl;
};
struct tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA {
  tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg Sup;
FILE* f;
};
struct tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw {
NI version;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* sources;
tySequence__sM4lkSb7zS6F7OVMvW9cffQ* names;
NimStringDesc* mappings;
NimStringDesc* file;
};
struct tyObject_Table__IARuioJxsgUIwpXiUkOgKg {
tySequence__SFipDZIkFtPcrLs0AGBBjQ* data;
NI counter;
};
struct tyTuple__8ZxhPt1NwfElsJs8zUSV9bg {
NI Field0;
NimStringDesc* Field1;
NimStringDesc* Field2;
};
struct tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA {
NimStringDesc* Field0;
tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* Field1;
};
struct tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA {
NCSTRING procname;
NI line;
NCSTRING filename;
};
typedef NU8 tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw;
struct tyObject_HSlice__dyNB5o2GYLzoO6FJ2RhiZw {
NI a;
NI b;
};
struct tySequence__qIo1GWQhO9cOgsAJDKUY8kw {
  TGenericSeq Sup;
  tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* data[SEQ_DECL_SIZE];
};
struct tySequence__CZrkID0OnHjQpN63AqYJwg {
  TGenericSeq Sup;
  tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ data[SEQ_DECL_SIZE];
};
struct tySequence__QbmGqFaLnb1IWWToREeaIA {
  TGenericSeq Sup;
  tyObject_StackTraceEntry__3r2E7OgmrW3VdUTaooCuyA data[SEQ_DECL_SIZE];
};
struct tySequence__QAzA9aOtpCCvcxe8jjx2Rmw {
  TGenericSeq Sup;
  tyEnum_ParserState__j5a0nuXg6IWyAxXC7BJVBw data[SEQ_DECL_SIZE];
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  TGenericSeq Sup;
  NimStringDesc* data[SEQ_DECL_SIZE];
};
struct tySequence__SFipDZIkFtPcrLs0AGBBjQ {
  TGenericSeq Sup;
  tyTuple__8ZxhPt1NwfElsJs8zUSV9bg data[SEQ_DECL_SIZE];
};
N_NIMCALL(NimStringDesc*, rawNewString)(NI cap);
N_LIB_PRIVATE N_NIMCALL(void, escapeJson__pureZjson_4371)(NimStringDesc* s, NimStringDesc** result);
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src);
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size);
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, resizeString)(NimStringDesc* dest, NI addlen);
N_LIB_PRIVATE N_NIMCALL(void, unsureAsgnRef)(void** dest, void* src);
N_LIB_PRIVATE N_NIMCALL(void, escapeJsonUnquoted__pureZjson_4350)(NimStringDesc* s, NimStringDesc** result);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___systemZdollars_3)(NI x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, toHex__pureZstrutils_1788)(NI x, NI len);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, addChar)(NimStringDesc* s, NIM_CHAR c);
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b);
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size);
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_2080)(tySequence__qIo1GWQhO9cOgsAJDKUY8kw* x, tySequence__qIo1GWQhO9cOgsAJDKUY8kw* y);
static N_INLINE(NI, len__pureZjson_2161)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ t);
static N_INLINE(void, nimZeroMem)(void* p, NI size);
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size);
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__pureZjson_2583)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_2063)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* a, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* b);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**, X5BX5D___pureZjson_2657)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* t, NimStringDesc* key);
N_LIB_PRIVATE N_NIMCALL(NI, len__pureZjson_3008)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* n);
N_LIB_PRIVATE N_NIMCALL(void, toUgly__pureZjson_4381)(NimStringDesc** result, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_167)(NimStringDesc** result, NI64 x);
static N_INLINE(void, addFloat__system_3130)(NimStringDesc** result, NF x);
N_LIB_PRIVATE N_NIMCALL(void, addFloatRoundtrip__system_3135)(NimStringDesc** result, NF x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyString)(NimStringDesc* src);
N_LIB_PRIVATE N_NIMCALL(void, initFromJson__pureZjson_5279)(NimStringDesc** dst, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* jsonNode, NimStringDesc** jsonPath);
N_LIB_PRIVATE N_NOINLINE(void*, newObj)(TNimType* typ, NI size);
static N_INLINE(void, asgnRef)(void** dest, void* src);
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y);
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr);
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y);
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y);
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NOINLINE(void, addZCT__system_5287)(tyObject_CellSeq__nav876ELHgxScHhs30CKiA* s, tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e, NCSTRING ename, NCSTRING procname, NCSTRING filename, NI line);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuFormatOpenArray)(NimStringDesc* formatstr, NimStringDesc** a, NI aLen_0);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZjson_5358)(tySet_tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A x);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, reprEnum)(NI e, TNimType* typ);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, copyStringRC1)(NimStringDesc* src);
static N_INLINE(void, nimGCunrefNoCycle)(void* p);
N_LIB_PRIVATE N_NIMCALL(void, genericSeqAssign)(void* dest, void* src, TNimType* mt);
N_LIB_PRIVATE N_NIMCALL(void, nimGCvisit)(void* d, NI op);
static N_NIMCALL(void, Marker_tySequence__CZrkID0OnHjQpN63AqYJwg)(void* p, NI op);
static N_NIMCALL(void, Marker_tyRef__LaYTJJQFT9b3qbn9c5fIsCog)(void* p, NI op);
static N_NIMCALL(void, Marker_tySequence__qIo1GWQhO9cOgsAJDKUY8kw)(void* p, NI op);
N_LIB_PRIVATE N_NIMCALL(void, initFromJson__pureZjson_5283)(NIM_BOOL* dst, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* jsonNode, NimStringDesc** jsonPath);
N_LIB_PRIVATE N_NIMCALL(tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA*, newFileStream__pureZstreams_832)(NimStringDesc* filename, tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w mode, NI bufSize);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, parseJson__pureZjson_5235)(tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc* filename, NIM_BOOL rawIntegers, NIM_BOOL rawFloats);
N_LIB_PRIVATE N_NIMCALL(void, open__pureZparsejson_97)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my, tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* input, NimStringDesc* filename, NIM_BOOL rawStringLiterals);
static N_INLINE(void, pushSafePoint)(TSafePoint* s);
N_LIB_PRIVATE N_NIMCALL(tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg, getTok__pureZparsejson_416)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, parseJson__pureZjson_5197)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NIM_BOOL rawIntegers, NIM_BOOL rawFloats, NI depth);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJStringMove__pureZjson_88)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJRawNumber__pureZjson_85)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJInt__pureZjson_91)(NI64 n);
N_LIB_PRIVATE N_NIMCALL(NI64, nsuParseBiggestInt)(NimStringDesc* s);
static N_INLINE(void, popSafePoint)(void);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isObj)(TNimType* obj, TNimType* subclass);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, reraiseException)(void);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJFloat__pureZjson_94)(NF n);
N_LIB_PRIVATE N_NIMCALL(NF, nsuParseFloat)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJBool__pureZjson_97)(NIM_BOOL b);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJNull__pureZjson_100)(void);
N_LIB_PRIVATE N_NOINLINE(void, raiseParseErr__pureZparsejson_571)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NimStringDesc* msg) __attribute__((noreturn));
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJObject__pureZjson_102)(void);
N_LIB_PRIVATE N_NIMCALL(void, initOrderedTable__pureZjson_104)(NI initialSize, tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* Result);
N_LIB_PRIVATE N_NIMCALL(void, eat__pureZparsejson_593)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg tok);
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___pureZjson_306)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ* t, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJArray__pureZjson_133)(void);
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_241)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* father, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* child);
N_LIB_PRIVATE N_NIMCALL(TGenericSeq*, incrSeqV3)(TGenericSeq* s, TNimType* typ);
static N_INLINE(void, close__pureZparsejson_151)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my);
N_LIB_PRIVATE N_NIMCALL(void, close__pureZlexbase_14)(tyObject_BaseLexer__1ErHTvYSm67JCofXisRUnA* L);
N_LIB_PRIVATE N_NIMCALL(void, nimLeaveFinally)(void);
N_LIB_PRIVATE N_NIMCALL(void, toPretty__pureZjson_4399)(NimStringDesc** result, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NI indent, NIM_BOOL ml, NIM_BOOL lstArr, NI currIndent);
N_LIB_PRIVATE N_NIMCALL(void, indent__pureZjson_4339)(NimStringDesc** s, NI i);
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n);
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, nsuRepeatChar)(NIM_CHAR c, NI count);
N_LIB_PRIVATE N_NIMCALL(void, nl__pureZjson_4347)(NimStringDesc** s, NIM_BOOL ml);
N_LIB_PRIVATE N_NIMCALL(NI, newIndent__pureZjson_4342)(NI curr, NI indent, NIM_BOOL ml);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___jsgen_6808)(tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw o);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1819)(NI n);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___jsgen_6815)(NimStringDesc** elements, NI elementsLen_0);
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1809)(NimStringDesc* s);
N_LIB_PRIVATE N_NIMCALL(NI, len__docgen_5888)(tyObject_Table__IARuioJxsgUIwpXiUkOgKg t);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_2, "\"", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_3, "\\n", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_4, "\\b", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_5, "\\f", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_6, "\\t", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_7, "\\u000b", 6);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_8, "\\r", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_9, "\\\"", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_10, "\\u000", 5);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_11, "\\u00", 4);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_12, "\\\\", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_13, "[", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_14, ",", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_15, "]", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_16, "{", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_17, ":", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_18, "}", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_19, "true", 4);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_20, "false", 5);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_21, "null", 4);
N_LIB_PRIVATE TNimType NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_;
extern TNimType NTIrefkeyerror__pZq9a89chzDPcYZo9bViSdp9aQ_;
extern TNimType NTIkeyerror__oKfiLNynQGoDF9bUMQFYNdw_;
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_25, "key not found: ", 15);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_26, "Incorrect JSON kind. Wanted \'$1\' in \'$2\' but got \'$3\'.", 54);
extern TNimType NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_;
extern TNimType NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_;
N_LIB_PRIVATE TNimType NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_;
extern TNimType NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_;
TNimNode* NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[8];
extern TNimType NTIstring__77mFvmsOLKik79ci2hXkHEg_;
extern TNimType NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_;
extern TNimType NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_;
N_LIB_PRIVATE TNimType NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_;
N_LIB_PRIVATE TNimType NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_;
extern TNimType NTIint__rR5Bzr1D5krxoo1NcNyeMA_;
N_LIB_PRIVATE TNimType NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_;
N_LIB_PRIVATE TNimType NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_;
N_LIB_PRIVATE TNimType NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_;
extern TNimType NTIrefioerror__0NUycR3lTt5ae7Mj01Qw8A_;
extern TNimType NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_;
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_30, "cannot read from file: ", 23);
extern TNimType NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_;
extern TNimType NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_;
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_34, "string literal as key", 21);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_35, "\012", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_36, " ", 1);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_37, ": ", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_38, "{}", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_39, "[]", 2);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_40, "version", 7);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_41, "sources", 7);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_42, "names", 5);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_43, "mappings", 8);
STRING_LITERAL(TM__9b9bytt1stv9cZ8uqII7HFgew_44, "file", 4);
extern tyObject_GcHeap__ZRn9bWCksoiGwT2drZZzyWQ gch__system_5240;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern TSafePoint* excHandler__system_2565;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
extern Exception* currException__system_2566;
static N_INLINE(void, nimCopyMem)(void* dest, void* source, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest, source, ((size_t) (size)));
}
static N_INLINE(void, copyMem__system_1733)(void* dest, void* source, NI size) {
	nimCopyMem(dest, source, size);
}
static N_INLINE(void, appendString)(NimStringDesc* dest, NimStringDesc* src) {
	{
		if (!!((src == ((NimStringDesc*) NIM_NIL)))) goto LA3_;
		copyMem__system_1733(((void*) ((&(*dest).data[(*dest).Sup.len]))), ((void*) ((*src).data)), ((NI) ((NI)((*src).Sup.len + ((NI) 1)))));
		(*dest).Sup.len += (*src).Sup.len;
	}
	LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, escapeJsonUnquoted__pureZjson_4350)(NimStringDesc* s, NimStringDesc** result) {
	{
		NIM_CHAR c;
		NI i;
		NI L;
		c = (NIM_CHAR)0;
		i = ((NI) 0);
		L = (s ? s->Sup.len : 0);
		{
			while (1) {
				if (!(i < L)) goto LA3;
				c = s->data[i];
				switch (((NU8)(c))) {
				case 10:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_3));
				}
				break;
				case 8:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_4));
				}
				break;
				case 12:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_5));
				}
				break;
				case 9:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_6));
				}
				break;
				case 11:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 6));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_7));
				}
				break;
				case 13:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_8));
				}
				break;
				case 34:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_9));
				}
				break;
				case 0 ... 7:
				{
					NimStringDesc* T12_;
					NimStringDesc* T13_;
					T12_ = NIM_NIL;
					T13_ = NIM_NIL;
					T13_ = dollar___systemZdollars_3(((NU8)(c)));
					T12_ = rawNewString((T13_ ? T13_->Sup.len : 0) + 5);
appendString(T12_, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_10));
appendString(T12_, T13_);
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T12_ ? T12_->Sup.len : 0) + 0));
appendString((*result), T12_);
				}
				break;
				case 14 ... 31:
				{
					NimStringDesc* T15_;
					NimStringDesc* T16_;
					T15_ = NIM_NIL;
					T16_ = NIM_NIL;
					T16_ = toHex__pureZstrutils_1788(((NU8)(c)), ((NI) 2));
					T15_ = rawNewString((T16_ ? T16_->Sup.len : 0) + 4);
appendString(T15_, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_11));
appendString(T15_, T16_);
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T15_ ? T15_->Sup.len : 0) + 0));
appendString((*result), T15_);
				}
				break;
				case 92:
				{
					unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_12));
				}
				break;
				default:
				{
					unsureAsgnRef((void**) (&(*result)), addChar((*result), c));
				}
				break;
				}
				i += ((NI) 1);
			} LA3: ;
		}
	}
}
N_LIB_PRIVATE N_NIMCALL(void, escapeJson__pureZjson_4371)(NimStringDesc* s, NimStringDesc** result) {
	unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_2));
	escapeJsonUnquoted__pureZjson_4350(s, result);
	unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_2));
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, escapeJson__pureZjson_4374)(NimStringDesc* s) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = rawNewString(((NI) ((NI)((s ? s->Sup.len : 0) + (NI)((NI32)((s ? s->Sup.len : 0)) >> (NU32)(((NI) 3)))))));
	escapeJson__pureZjson_4371(s, (&result));
	return result;
}
static N_INLINE(int, nimCmpMem)(void* a, void* b, NI size) {
	int result;
	result = (int)0;
	result = memcmp(a, b, ((size_t) (size)));
	return result;
}
static N_INLINE(NIM_BOOL, equalMem__system_1741)(void* a, void* b, NI size) {
	NIM_BOOL result;
	int T1_;
	result = (NIM_BOOL)0;
	T1_ = (int)0;
	T1_ = nimCmpMem(a, b, size);
	result = (T1_ == ((NI32) 0));
	return result;
}
static N_INLINE(NIM_BOOL, eqStrings)(NimStringDesc* a, NimStringDesc* b) {
	NIM_BOOL result;
	NI alen;
	NI blen;
{	result = (NIM_BOOL)0;
	alen = (a ? a->Sup.len : 0);
	blen = (b ? b->Sup.len : 0);
	{
		if (!(alen == blen)) goto LA3_;
		{
			if (!(alen == ((NI) 0))) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = equalMem__system_1741(((void*) ((&a->data[((NI) 0)]))), ((void*) ((&b->data[((NI) 0)]))), ((NI) (alen)));
		goto BeforeRet_;
	}
	LA3_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NI, len__pureZjson_2161)(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ t) {
	NI result;
	result = (NI)0;
	result = t.counter;
	return result;
}
static N_INLINE(void, nimSetMem__systemZmemory_7)(void* a, int v, NI size) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a, v, ((size_t) (size)));
}
static N_INLINE(void, nimZeroMem)(void* p, NI size) {
	nimSetMem__systemZmemory_7(p, ((int) 0), size);
}
static N_INLINE(NIM_BOOL, isFilled__pureZcollectionsZtables_31)(NI hcode) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = !((hcode == ((NI) 0)));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___pureZjson_2063)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* a, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* b) {
	NIM_BOOL result;
{	result = (NIM_BOOL)0;
	{
		if (!(a == 0)) goto LA3_;
		{
			if (!(b == 0)) goto LA7_;
			result = NIM_TRUE;
			goto BeforeRet_;
		}
		LA7_: ;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		NIM_BOOL T10_;
		T10_ = (NIM_BOOL)0;
		T10_ = (b == 0);
		if (T10_) goto LA11_;
		T10_ = !(((*a).kind == (*b).kind));
		LA11_: ;
		if (!T10_) goto LA12_;
		result = NIM_FALSE;
		goto BeforeRet_;
	}
	goto LA1_;
	LA12_: ;
	{
		switch ((*a).kind) {
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4):
		{
			result = eqStrings((*a)._kind_1.str, (*b)._kind_1.str);
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2):
		{
			result = ((*a)._kind_2.num == (*b)._kind_2.num);
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 3):
		{
			result = ((*a)._kind_3.fnum == (*b)._kind_3.fnum);
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1):
		{
			result = ((*a)._kind_4.bval == (*b)._kind_4.bval);
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0):
		{
			result = NIM_TRUE;
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6):
		{
			result = eqeq___pureZjson_2080((*a)._kind_7.elems, (*b)._kind_7.elems);
		}
		break;
		case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5):
		{
			{
				NI T24_;
				NI T25_;
				T24_ = (NI)0;
				T24_ = len__pureZjson_2161((*a)._kind_6.fields);
				T25_ = (NI)0;
				T25_ = len__pureZjson_2161((*b)._kind_6.fields);
				if (!!((T24_ == T25_))) goto LA26_;
				result = NIM_FALSE;
				goto BeforeRet_;
			}
			LA26_: ;
			{
				NimStringDesc* key;
				tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val;
				tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ colontmp_;
				NI L;
				key = NIM_NIL;
				val = NIM_NIL;
				nimZeroMem((void*)(&colontmp_), sizeof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ));
				colontmp_.data = (*a)._kind_6.fields.data;
				colontmp_.counter = (*a)._kind_6.fields.counter;
				colontmp_.first = (*a)._kind_6.fields.first;
				colontmp_.last = (*a)._kind_6.fields.last;
				L = len__pureZjson_2161(colontmp_);
				{
					NI h;
					if (!(((NI) 0) < colontmp_.counter)) goto LA31_;
					h = colontmp_.first;
					{
						while (1) {
							NI nxt;
							if (!(((NI) 0) <= h)) goto LA34;
							nxt = colontmp_.data->data[h].Field1;
							{
								NIM_BOOL T37_;
								T37_ = (NIM_BOOL)0;
								T37_ = isFilled__pureZcollectionsZtables_31(colontmp_.data->data[h].Field0);
								if (!T37_) goto LA38_;
								key = colontmp_.data->data[h].Field2;
								val = colontmp_.data->data[h].Field3;
								{
									NIM_BOOL T42_;
									T42_ = (NIM_BOOL)0;
									T42_ = hasKey__pureZjson_2583((*b)._kind_6.fields, key);
									if (!!(T42_)) goto LA43_;
									result = NIM_FALSE;
									goto BeforeRet_;
								}
								LA43_: ;
								{
									tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g** T47_;
									NIM_BOOL T48_;
									T47_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**)0;
									T47_ = X5BX5D___pureZjson_2657((&(*b)._kind_6.fields), key);
									T48_ = (NIM_BOOL)0;
									T48_ = eqeq___pureZjson_2063((*T47_), val);
									if (!!(T48_)) goto LA49_;
									result = NIM_FALSE;
									goto BeforeRet_;
								}
								LA49_: ;
							}
							LA38_: ;
							h = nxt;
						} LA34: ;
					}
				}
				LA31_: ;
			}
			result = NIM_TRUE;
		}
		break;
		}
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, len__pureZjson_3008)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* n) {
	NI result;
	result = (NI)0;
	switch ((*n).kind) {
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6):
	{
		NI T2_;
		T2_ = ((*n)._kind_7.elems ? (*n)._kind_7.elems->Sup.len : 0);
		result = T2_;
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5):
	{
		result = len__pureZjson_2161((*n)._kind_6.fields);
	}
	break;
	default:
	{
	}
	break;
	}
	return result;
}
static N_INLINE(void, addFloat__system_3130)(NimStringDesc** result, NF x) {
	addFloatRoundtrip__system_3135(result, x);
}
N_LIB_PRIVATE N_NIMCALL(void, toUgly__pureZjson_4381)(NimStringDesc** result, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node) {
	NIM_BOOL comma;
	comma = NIM_FALSE;
	switch ((*node).kind) {
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6):
	{
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_13));
		{
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g** child;
			tySequence__qIo1GWQhO9cOgsAJDKUY8kw* colontmp_;
			NI i;
			NI L;
			NI T3_;
			child = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**)0;
			colontmp_ = NIM_NIL;
			colontmp_ = (*node)._kind_7.elems;
			i = ((NI) 0);
			T3_ = (colontmp_ ? colontmp_->Sup.len : 0);
			L = T3_;
			{
				while (1) {
					if (!(i < L)) goto LA5;
					child = &colontmp_->data[i];
					{
						if (!comma) goto LA8_;
						unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_14));
					}
					goto LA6_;
					LA8_: ;
					{
						comma = NIM_TRUE;
					}
					LA6_: ;
					toUgly__pureZjson_4381(result, (*child));
					i += ((NI) 1);
				} LA5: ;
			}
		}
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_15));
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5):
	{
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_16));
		{
			NimStringDesc* key;
			tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* value;
			tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ colontmp__2;
			NI L_2;
			key = NIM_NIL;
			value = NIM_NIL;
			nimZeroMem((void*)(&colontmp__2), sizeof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ));
			colontmp__2.data = (*node)._kind_6.fields.data;
			colontmp__2.counter = (*node)._kind_6.fields.counter;
			colontmp__2.first = (*node)._kind_6.fields.first;
			colontmp__2.last = (*node)._kind_6.fields.last;
			L_2 = len__pureZjson_2161(colontmp__2);
			{
				NI h;
				if (!(((NI) 0) < colontmp__2.counter)) goto LA15_;
				h = colontmp__2.first;
				{
					while (1) {
						NI nxt;
						if (!(((NI) 0) <= h)) goto LA18;
						nxt = colontmp__2.data->data[h].Field1;
						{
							NIM_BOOL T21_;
							T21_ = (NIM_BOOL)0;
							T21_ = isFilled__pureZcollectionsZtables_31(colontmp__2.data->data[h].Field0);
							if (!T21_) goto LA22_;
							key = colontmp__2.data->data[h].Field2;
							value = colontmp__2.data->data[h].Field3;
							{
								if (!comma) goto LA26_;
								unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_14));
							}
							goto LA24_;
							LA26_: ;
							{
								comma = NIM_TRUE;
							}
							LA24_: ;
							escapeJson__pureZjson_4371(key, result);
							unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_17));
							toUgly__pureZjson_4381(result, value);
						}
						LA22_: ;
						h = nxt;
					} LA18: ;
				}
			}
			LA15_: ;
		}
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_18));
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4):
	{
		{
			if (!(*node).isUnquoted) goto LA32_;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), ((*node)._kind_1.str ? (*node)._kind_1.str->Sup.len : 0) + 0));
appendString((*result), (*node)._kind_1.str);
		}
		goto LA30_;
		LA32_: ;
		{
			escapeJson__pureZjson_4371((*node)._kind_1.str, result);
		}
		LA30_: ;
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2):
	{
		addInt__stdZprivateZdigitsutils_167(result, (*node)._kind_2.num);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 3):
	{
		addFloat__system_3130(result, (*node)._kind_3.fnum);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1):
	{
		NimStringDesc* T38_;
		T38_ = NIM_NIL;
		{
			if (!(*node)._kind_4.bval) goto LA41_;
			T38_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_19));
		}
		goto LA39_;
		LA41_: ;
		{
			T38_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_20));
		}
		LA39_: ;
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T38_ ? T38_->Sup.len : 0) + 0));
appendString((*result), T38_);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0):
	{
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 4));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_21));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, dollar___pureZjson_4484)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node) {
	NimStringDesc* result;
	NI T1_;
	result = NIM_NIL;
	T1_ = (NI)0;
	T1_ = len__pureZjson_3008(node);
	result = rawNewString(((NI) ((NI)((NU32)(T1_) << (NU32)(((NI) 1))))));
	toUgly__pureZjson_4381((&result), node);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__pureZjson_3171)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NimStringDesc* key) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = hasKey__pureZjson_2583((*node)._kind_6.fields, key);
	return result;
}
static N_INLINE(NI, pluspercent___system_696)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) + (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(void, incRef__system_5331)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = pluspercent___system_696((*c).refcount, ((NI) 8));
}
static N_INLINE(NI, minuspercent___system_716)(NI x, NI y) {
	NI result;
	result = (NI)0;
	result = ((NI) ((NU)((NU32)(((NU) (x))) - (NU32)(((NU) (y))))));
	return result;
}
static N_INLINE(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*, usrToCell__system_5293)(void* usr) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* result;
	NI T1_;
	result = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = (NI)0;
	T1_ = minuspercent___system_716(((NI) (ptrdiff_t) (usr)), ((NI) 8));
	result = ((tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*) (T1_));
	return result;
}
static N_INLINE(NIM_BOOL, ltpercent___system_1005)(NI x, NI y) {
	NIM_BOOL result;
	result = (NIM_BOOL)0;
	result = ((NU32)(((NU) (x))) < (NU32)(((NU) (y))));
	return result;
}
static N_INLINE(void, rtlAddZCT__system_5336)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	addZCT__system_5287((&gch__system_5240.zct), c);
}
static N_INLINE(void, decRef__system_5338)(tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* c) {
	(*c).refcount = minuspercent___system_716((*c).refcount, ((NI) 8));
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ltpercent___system_1005((*c).refcount, ((NI) 8));
		if (!T3_) goto LA4_;
		rtlAddZCT__system_5336(c);
	}
	LA4_: ;
}
static N_INLINE(void, asgnRef)(void** dest, void* src) {
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T5_;
		if (!!((src == NIM_NIL))) goto LA3_;
		T5_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T5_ = usrToCell__system_5293(src);
		incRef__system_5331(T5_);
	}
	LA3_: ;
	{
		tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T10_;
		if (!!(((*dest) == NIM_NIL))) goto LA8_;
		T10_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
		T10_ = usrToCell__system_5293((*dest));
		decRef__system_5338(T10_);
	}
	LA8_: ;
	(*dest) = src;
}
static N_INLINE(void, nimGCunrefNoCycle)(void* p) {
	tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g* T1_;
	T1_ = (tyObject_Cell__nhn83Yf9cX7rcmG5W9b4oa6g*)0;
	T1_ = usrToCell__system_5293(p);
	decRef__system_5338(T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, initFromJson__pureZjson_5279)(NimStringDesc** dst, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* jsonNode, NimStringDesc** jsonPath) {
	{
		NIM_BOOL T3_;
		tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw* T6_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_2063(jsonNode, ((tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) NIM_NIL));
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw*) newObj((&NTIrefkeyerror__pZq9a89chzDPcYZo9bViSdp9aQ_), sizeof(tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw));
		(*T6_).Sup.Sup.Sup.Sup.m_type = (&NTIkeyerror__oKfiLNynQGoDF9bUMQFYNdw_);
		(*T6_).Sup.Sup.Sup.name = "KeyError";
		T7_ = NIM_NIL;
		T7_ = rawNewString(((*jsonPath) ? (*jsonPath)->Sup.len : 0) + 15);
appendString(T7_, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_25));
appendString(T7_, (*jsonPath));
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.message), T7_);
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T6_, "KeyError", "initFromJson", "json.nim", 1050);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* msgX60gensym96_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T11_;
		tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ* T12_;
		NimStringDesc* T13_;
		if (!!(((17 &((NU8)1<<((NU)((*jsonNode).kind)&7U)))!=0))) goto LA9_;
		nimZeroMem((void*)T11_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T11_[0] = dollar___pureZjson_5358(17);
		T11_[1] = copyString((*jsonPath));
		T11_[2] = reprEnum((NI)(*jsonNode).kind, (&NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_));
		msgX60gensym96_ = nsuFormatOpenArray(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_26), T11_, 3);
		T12_ = NIM_NIL;
		T12_ = (tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ*) newObj((&NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_), sizeof(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ));
		(*T12_).Sup.Sup.Sup.Sup.m_type = (&NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_);
		(*T12_).Sup.Sup.Sup.name = "JsonKindError";
		T13_ = NIM_NIL;
		T13_ = (*T12_).Sup.Sup.Sup.message; (*T12_).Sup.Sup.Sup.message = copyStringRC1(msgX60gensym96_);
		if (T13_) nimGCunrefNoCycle(T13_);
		asgnRef((void**) (&(*T12_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T12_, "JsonKindError", "initFromJson", "json.nim", 1057);
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
	{
		if (!((*jsonNode).kind == ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0))) goto LA16_;
		unsureAsgnRef((void**) (&(*dst)), ((NimStringDesc*) NIM_NIL));
	}
	goto LA14_;
	LA16_: ;
	{
		unsureAsgnRef((void**) (&(*dst)), copyString((*jsonNode)._kind_1.str));
	}
	LA14_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, to__stdZjsonutils_582)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node) {
	NimStringDesc* result;
	NimStringDesc* jsonPath;
	result = NIM_NIL;
	jsonPath = ((NimStringDesc*) NIM_NIL);
	initFromJson__pureZjson_5279((&result), node, (&jsonPath));
	return result;
}
static N_NIMCALL(void, Marker_tySequence__CZrkID0OnHjQpN63AqYJwg)(void* p, NI op) {
	tySequence__CZrkID0OnHjQpN63AqYJwg* a;
	NI T1_;
	a = (tySequence__CZrkID0OnHjQpN63AqYJwg*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_].Field2, op);
	nimGCvisit((void*)a->data[T1_].Field3, op);
	}
}
static N_NIMCALL(void, Marker_tyRef__LaYTJJQFT9b3qbn9c5fIsCog)(void* p, NI op) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* a;
	a = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*)p;
	switch ((*a).kind) {
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4):
	nimGCvisit((void*)(*a)._kind_1.str, op);
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2):
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 3):
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1):
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0):
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5):
	nimGCvisit((void*)(*a)._kind_6.fields.data, op);
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6):
	nimGCvisit((void*)(*a)._kind_7.elems, op);
	break;
	} 
}
static N_NIMCALL(void, Marker_tySequence__qIo1GWQhO9cOgsAJDKUY8kw)(void* p, NI op) {
	tySequence__qIo1GWQhO9cOgsAJDKUY8kw* a;
	NI T1_;
	a = (tySequence__qIo1GWQhO9cOgsAJDKUY8kw*)p;
	T1_ = (NI)0;
	for (T1_ = 0; T1_ < (a ? a->Sup.len : 0); T1_++) {
	nimGCvisit((void*)a->data[T1_], op);
	}
}
N_LIB_PRIVATE N_NIMCALL(tySequence__qIo1GWQhO9cOgsAJDKUY8kw*, getElems__pureZjson_226)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* n, tySequence__qIo1GWQhO9cOgsAJDKUY8kw* default_0) {
	tySequence__qIo1GWQhO9cOgsAJDKUY8kw* result;
{	result = NIM_NIL;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (n == 0);
		if (T3_) goto LA4_;
		T3_ = !(((*n).kind == ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6)));
		LA4_: ;
		if (!T3_) goto LA5_;
		genericSeqAssign((&result), default_0, (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_));
		goto BeforeRet_;
	}
	goto LA1_;
	LA5_: ;
	{
		genericSeqAssign((&result), (*n)._kind_7.elems, (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_));
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initFromJson__pureZjson_5283)(NIM_BOOL* dst, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* jsonNode, NimStringDesc** jsonPath) {
	{
		NIM_BOOL T3_;
		tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw* T6_;
		NimStringDesc* T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = eqeq___pureZjson_2063(jsonNode, ((tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) NIM_NIL));
		if (!T3_) goto LA4_;
		T6_ = NIM_NIL;
		T6_ = (tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw*) newObj((&NTIrefkeyerror__pZq9a89chzDPcYZo9bViSdp9aQ_), sizeof(tyObject_KeyError__oKfiLNynQGoDF9bUMQFYNdw));
		(*T6_).Sup.Sup.Sup.Sup.m_type = (&NTIkeyerror__oKfiLNynQGoDF9bUMQFYNdw_);
		(*T6_).Sup.Sup.Sup.name = "KeyError";
		T7_ = NIM_NIL;
		T7_ = rawNewString(((*jsonPath) ? (*jsonPath)->Sup.len : 0) + 15);
appendString(T7_, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_25));
appendString(T7_, (*jsonPath));
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.message), T7_);
		asgnRef((void**) (&(*T6_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T6_, "KeyError", "initFromJson", "json.nim", 1050);
	}
	goto LA1_;
	LA4_: ;
	{
		NimStringDesc* msgX60gensym100_;
		tyArray__24KAM9afIUgUaqBaEBB6r9bg T11_;
		tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ* T12_;
		NimStringDesc* T13_;
		if (!!(((2 &((NU8)1<<((NU)((*jsonNode).kind)&7U)))!=0))) goto LA9_;
		nimZeroMem((void*)T11_, sizeof(tyArray__24KAM9afIUgUaqBaEBB6r9bg));
		T11_[0] = dollar___pureZjson_5358(2);
		T11_[1] = copyString((*jsonPath));
		T11_[2] = reprEnum((NI)(*jsonNode).kind, (&NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_));
		msgX60gensym100_ = nsuFormatOpenArray(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_26), T11_, 3);
		T12_ = NIM_NIL;
		T12_ = (tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ*) newObj((&NTIrefjsonkinderror__yYt4rn61ispQzTJd12bbFw_), sizeof(tyObject_JsonKindError__AoNiOfrNmMaOu0Lc0TiKiQ));
		(*T12_).Sup.Sup.Sup.Sup.m_type = (&NTIjsonkinderror__AoNiOfrNmMaOu0Lc0TiKiQ_);
		(*T12_).Sup.Sup.Sup.name = "JsonKindError";
		T13_ = NIM_NIL;
		T13_ = (*T12_).Sup.Sup.Sup.message; (*T12_).Sup.Sup.Sup.message = copyStringRC1(msgX60gensym100_);
		if (T13_) nimGCunrefNoCycle(T13_);
		asgnRef((void**) (&(*T12_).Sup.Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T12_, "JsonKindError", "initFromJson", "json.nim", 1057);
	}
	goto LA1_;
	LA9_: ;
	LA1_: ;
	(*dst) = (*jsonNode)._kind_4.bval;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, to__extccomp_2285)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node) {
	NIM_BOOL result;
	NimStringDesc* jsonPath;
	result = (NIM_BOOL)0;
	jsonPath = ((NimStringDesc*) NIM_NIL);
	initFromJson__pureZjson_5283((&result), node, (&jsonPath));
	return result;
}
static N_INLINE(void, pushSafePoint)(TSafePoint* s) {
	(*s).prev = excHandler__system_2565;
	excHandler__system_2565 = s;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJStringMove__pureZjson_88)(NimStringDesc* s) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4);
	result = T1_;
	asgnRef((void**) (&(*result)._kind_1.str), s);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJRawNumber__pureZjson_85)(NimStringDesc* s) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4);
	T2_ = NIM_NIL;
	T2_ = (*T1_)._kind_1.str; (*T1_)._kind_1.str = copyStringRC1(s);
	if (T2_) nimGCunrefNoCycle(T2_);
	(*T1_).isUnquoted = NIM_TRUE;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJInt__pureZjson_91)(NI64 n) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2);
	(*T1_)._kind_2.num = n;
	result = T1_;
	return result;
}
static N_INLINE(void, popSafePoint)(void) {
	excHandler__system_2565 = (*excHandler__system_2565).prev;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = NIM_NIL;
	result = currException__system_2566;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	asgnRef((void**) (&currException__system_2566), (*currException__system_2566).up);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJFloat__pureZjson_94)(NF n) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 3);
	(*T1_)._kind_3.fnum = n;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJBool__pureZjson_97)(NIM_BOOL b) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1);
	(*T1_)._kind_4.bval = b;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJNull__pureZjson_100)(void) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJObject__pureZjson_102)(void) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5);
	initOrderedTable__pureZjson_104(((NI) 2), (&(*T1_)._kind_6.fields));
	result = T1_;
	return result;
}
static N_INLINE(void, X5BX5Deq___pureZjson_1942)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* obj, NimStringDesc* key, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val) {
	X5BX5Deq___pureZjson_306((&(*obj)._kind_6.fields), key, val);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, newJArray__pureZjson_133)(void) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6);
	if ((*T1_)._kind_7.elems) { nimGCunrefNoCycle((*T1_)._kind_7.elems); (*T1_)._kind_7.elems = NIM_NIL; }
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, add__pureZjson_241)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* father, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* child) {
	NI T1_;
	asgnRef((void**) (&(*father)._kind_7.elems), (tySequence__qIo1GWQhO9cOgsAJDKUY8kw*) incrSeqV3((TGenericSeq*)((*father)._kind_7.elems), (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_)));
	T1_ = (*father)._kind_7.elems->Sup.len++;
	asgnRef((void**) (&(*father)._kind_7.elems->data[T1_]), child);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, parseJson__pureZjson_5197)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* p, NIM_BOOL rawIntegers, NIM_BOOL rawFloats, NI depth) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* volatile result;
	result = NIM_NIL;
	switch ((*p).tok) {
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T2_;
		result = newJStringMove__pureZjson_88((*p).a);
		unsureAsgnRef((void**) (&(*p).a), ((NimStringDesc*) NIM_NIL));
		T2_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T2_ = getTok__pureZparsejson_416(p);
		(void)(T2_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 3):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T12_;
		{
			if (!rawIntegers) goto LA6_;
			result = newJRawNumber__pureZjson_85((*p).a);
		}
		goto LA4_;
		LA6_: ;
		{
			TSafePoint TM__9b9bytt1stv9cZ8uqII7HFgew_32;
			NI64 T9_;
			pushSafePoint(&TM__9b9bytt1stv9cZ8uqII7HFgew_32);
			TM__9b9bytt1stv9cZ8uqII7HFgew_32.status = setjmp(TM__9b9bytt1stv9cZ8uqII7HFgew_32.context);
			if (TM__9b9bytt1stv9cZ8uqII7HFgew_32.status == 0) {
			T9_ = (NI64)0;
			T9_ = nsuParseBiggestInt((*p).a);
			result = newJInt__pureZjson_91(T9_);
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
					TM__9b9bytt1stv9cZ8uqII7HFgew_32.status = 0;
					result = newJRawNumber__pureZjson_85((*p).a);
					popCurrentException();
				}
			}
			if (TM__9b9bytt1stv9cZ8uqII7HFgew_32.status != 0) reraiseException();
		}
		LA4_: ;
		T12_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T12_ = getTok__pureZparsejson_416(p);
		(void)(T12_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 4):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T22_;
		{
			if (!rawFloats) goto LA16_;
			result = newJRawNumber__pureZjson_85((*p).a);
		}
		goto LA14_;
		LA16_: ;
		{
			TSafePoint TM__9b9bytt1stv9cZ8uqII7HFgew_33;
			NF T19_;
			pushSafePoint(&TM__9b9bytt1stv9cZ8uqII7HFgew_33);
			TM__9b9bytt1stv9cZ8uqII7HFgew_33.status = setjmp(TM__9b9bytt1stv9cZ8uqII7HFgew_33.context);
			if (TM__9b9bytt1stv9cZ8uqII7HFgew_33.status == 0) {
			T19_ = (NF)0;
			T19_ = nsuParseFloat((*p).a);
			result = newJFloat__pureZjson_94(T19_);
			popSafePoint();
			}
			else {
				popSafePoint();
				if (isObj(nimBorrowCurrentException()->Sup.m_type, (&NTIvalueerror__5lcTdgqMq62cNGRwBb0thA_))) {
					TM__9b9bytt1stv9cZ8uqII7HFgew_33.status = 0;
					result = newJRawNumber__pureZjson_85((*p).a);
					popCurrentException();
				}
			}
			if (TM__9b9bytt1stv9cZ8uqII7HFgew_33.status != 0) reraiseException();
		}
		LA14_: ;
		T22_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T22_ = getTok__pureZparsejson_416(p);
		(void)(T22_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 5):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T24_;
		result = newJBool__pureZjson_97(NIM_TRUE);
		T24_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T24_ = getTok__pureZparsejson_416(p);
		(void)(T24_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 6):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T26_;
		result = newJBool__pureZjson_97(NIM_FALSE);
		T26_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T26_ = getTok__pureZparsejson_416(p);
		(void)(T26_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 7):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T28_;
		result = newJNull__pureZjson_100();
		T28_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T28_ = getTok__pureZparsejson_416(p);
		(void)(T28_);
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 8):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T34_;
		{
			if (!(((NI) 1000) < depth)) goto LA32_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_18));
		}
		LA32_: ;
		result = newJObject__pureZjson_102();
		T34_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T34_ = getTok__pureZparsejson_416(p);
		(void)(T34_);
		{
			while (1) {
				NimStringDesc* key;
				tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T41_;
				tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val;
				tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T46_;
				if (!!(((*p).tok == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9)))) goto LA36;
				{
					if (!!(((*p).tok == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 2)))) goto LA39_;
					raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_34));
				}
				LA39_: ;
				key = copyString((*p).a);
				T41_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
				T41_ = getTok__pureZparsejson_416(p);
				(void)(T41_);
				eat__pureZparsejson_593(p, ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 12));
				val = parseJson__pureZjson_5197(p, rawIntegers, rawFloats, (NI)(depth + ((NI) 1)));
				X5BX5Deq___pureZjson_1942(result, key, val);
				{
					if (!!(((*p).tok == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13)))) goto LA44_;
					goto LA35;
				}
				LA44_: ;
				T46_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
				T46_ = getTok__pureZparsejson_416(p);
				(void)(T46_);
			} LA36: ;
		} LA35: ;
		eat__pureZparsejson_593(p, ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9));
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 10):
	{
		tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T52_;
		{
			if (!(((NI) 1000) < depth)) goto LA50_;
			raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_15));
		}
		LA50_: ;
		result = newJArray__pureZjson_133();
		T52_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
		T52_ = getTok__pureZparsejson_416(p);
		(void)(T52_);
		{
			while (1) {
				tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T55_;
				tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T60_;
				if (!!(((*p).tok == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11)))) goto LA54;
				T55_ = NIM_NIL;
				T55_ = parseJson__pureZjson_5197(p, rawIntegers, rawFloats, (NI)(depth + ((NI) 1)));
				add__pureZjson_241(result, T55_);
				{
					if (!!(((*p).tok == ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13)))) goto LA58_;
					goto LA53;
				}
				LA58_: ;
				T60_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
				T60_ = getTok__pureZparsejson_416(p);
				(void)(T60_);
			} LA54: ;
		} LA53: ;
		eat__pureZparsejson_593(p, ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11));
	}
	break;
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 0):
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 9):
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 11):
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 12):
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 13):
	case ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 1):
	{
		raiseParseErr__pureZparsejson_571((&(*p)), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_16));
	}
	break;
	}
	return result;
}
static N_INLINE(void, close__pureZparsejson_151)(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA* my) {
	close__pureZlexbase_14(&my->Sup);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, parseJson__pureZjson_5235)(tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg* s, NimStringDesc* filename, NIM_BOOL rawIntegers, NIM_BOOL rawFloats) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* volatile result;
	tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA p;
	TSafePoint TM__9b9bytt1stv9cZ8uqII7HFgew_31;
	tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg T1_;
	result = NIM_NIL;
	nimZeroMem((void*)(&p), sizeof(tyObject_JsonParser__w6FDVeQ36QibBeDgwddDMA));
	p.Sup.Sup.m_type = (&NTIjsonparser__w6FDVeQ36QibBeDgwddDMA_);
	open__pureZparsejson_97((&p), s, filename, NIM_FALSE);
	pushSafePoint(&TM__9b9bytt1stv9cZ8uqII7HFgew_31);
	TM__9b9bytt1stv9cZ8uqII7HFgew_31.status = setjmp(TM__9b9bytt1stv9cZ8uqII7HFgew_31.context);
	if (TM__9b9bytt1stv9cZ8uqII7HFgew_31.status == 0) {
	T1_ = (tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg)0;
	T1_ = getTok__pureZparsejson_416((&p));
	(void)(T1_);
	result = parseJson__pureZjson_5197((&p), rawIntegers, rawFloats, ((NI) 0));
	eat__pureZparsejson_593((&p), ((tyEnum_TokKind__C8Hu9bDXSJDTgDmOq9aRd9agg) 1));
	popSafePoint();
	}
	else {
		popSafePoint();
	}
	{
		close__pureZparsejson_151((&p));
		if (TM__9b9bytt1stv9cZ8uqII7HFgew_31.status != 0) nimLeaveFinally();
	}
	if (TM__9b9bytt1stv9cZ8uqII7HFgew_31.status != 0) reraiseException();
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, parseFile__pureZjson_5247)(NimStringDesc* filename) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA* stream;
	result = NIM_NIL;
	stream = newFileStream__pureZstreams_832(filename, ((tyEnum_FileMode__l9cwNsPPKSvz36rQZGh2S7w) 0), ((NI) -1));
	{
		tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA* T5_;
		NimStringDesc* T6_;
		if (!(stream == ((tyObject_FileStreamObj__tYEhzw9bqtvCVwdyniGzYfA*) NIM_NIL))) goto LA3_;
		T5_ = NIM_NIL;
		T5_ = (tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA*) newObj((&NTIrefioerror__0NUycR3lTt5ae7Mj01Qw8A_), sizeof(tyObject_IOError__5GCiDuy5Wsuc9an2QZvqgIA));
		(*T5_).Sup.Sup.Sup.m_type = (&NTIioerror__5GCiDuy5Wsuc9an2QZvqgIA_);
		(*T5_).Sup.Sup.name = "IOError";
		T6_ = NIM_NIL;
		T6_ = rawNewString((filename ? filename->Sup.len : 0) + 23);
appendString(T6_, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_30));
appendString(T6_, filename);
		asgnRef((void**) (&(*T5_).Sup.Sup.message), T6_);
		asgnRef((void**) (&(*T5_).Sup.Sup.parent), ((Exception*) NIM_NIL));
		raiseExceptionEx((Exception*)T5_, "IOError", "parseFile", "json.nim", 1042);
	}
	LA3_: ;
	result = parseJson__pureZjson_5235((*((tyObject_StreamObj__QJOHa8TkfjsZVXTbMulWFg**) (&(stream)))), filename, NIM_FALSE, NIM_FALSE);
	return result;
}
static N_INLINE(NimStringDesc*, spaces__pureZstrutils_1029)(NI n) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = nsuRepeatChar(32, n);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, indent__pureZjson_4339)(NimStringDesc** s, NI i) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	T1_ = spaces__pureZstrutils_1029(((NI) (i)));
	unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T1_ ? T1_->Sup.len : 0) + 0));
appendString((*s), T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, nl__pureZjson_4347)(NimStringDesc** s, NIM_BOOL ml) {
	NimStringDesc* T1_;
	T1_ = NIM_NIL;
	{
		if (!ml) goto LA4_;
		T1_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_35));
	}
	goto LA2_;
	LA4_: ;
	{
		T1_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_36));
	}
	LA2_: ;
	unsureAsgnRef((void**) (&(*s)), resizeString((*s), (T1_ ? T1_->Sup.len : 0) + 0));
appendString((*s), T1_);
}
N_LIB_PRIVATE N_NIMCALL(NI, newIndent__pureZjson_4342)(NI curr, NI indent, NIM_BOOL ml) {
	NI result;
{	result = (NI)0;
	{
		if (!ml) goto LA3_;
		result = (NI)(curr + indent);
		goto BeforeRet_;
	}
	goto LA1_;
	LA3_: ;
	{
		result = indent;
		goto BeforeRet_;
	}
	LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, toPretty__pureZjson_4399)(NimStringDesc** result, tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NI indent, NIM_BOOL ml, NIM_BOOL lstArr, NI currIndent) {
	switch ((*node).kind) {
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 5):
	{
		{
			if (!lstArr) goto LA4_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA4_: ;
		{
			NI T8_;
			NI i;
			T8_ = (NI)0;
			T8_ = len__pureZjson_2161((*node)._kind_6.fields);
			if (!(((NI) 0) < T8_)) goto LA9_;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_16));
			nl__pureZjson_4347(result, ml);
			i = ((NI) 0);
			{
				NimStringDesc* key;
				tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* val;
				tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ colontmp_;
				NI L;
				key = NIM_NIL;
				val = NIM_NIL;
				nimZeroMem((void*)(&colontmp_), sizeof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ));
				colontmp_.data = (*node)._kind_6.fields.data;
				colontmp_.counter = (*node)._kind_6.fields.counter;
				colontmp_.first = (*node)._kind_6.fields.first;
				colontmp_.last = (*node)._kind_6.fields.last;
				L = len__pureZjson_2161(colontmp_);
				{
					NI h;
					if (!(((NI) 0) < colontmp_.counter)) goto LA14_;
					h = colontmp_.first;
					{
						while (1) {
							NI nxt;
							if (!(((NI) 0) <= h)) goto LA17;
							nxt = colontmp_.data->data[h].Field1;
							{
								NIM_BOOL T20_;
								NI T27_;
								NI T28_;
								T20_ = (NIM_BOOL)0;
								T20_ = isFilled__pureZcollectionsZtables_31(colontmp_.data->data[h].Field0);
								if (!T20_) goto LA21_;
								key = colontmp_.data->data[h].Field2;
								val = colontmp_.data->data[h].Field3;
								{
									if (!(((NI) 0) < i)) goto LA25_;
									unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_14));
									nl__pureZjson_4347(result, ml);
								}
								LA25_: ;
								i += ((NI) 1);
								T27_ = (NI)0;
								T27_ = newIndent__pureZjson_4342(currIndent, indent, ml);
								indent__pureZjson_4339(result, T27_);
								escapeJson__pureZjson_4371(key, result);
								unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_37));
								T28_ = (NI)0;
								T28_ = newIndent__pureZjson_4342(currIndent, indent, ml);
								toPretty__pureZjson_4399(result, val, indent, ml, NIM_FALSE, T28_);
							}
							LA21_: ;
							h = nxt;
						} LA17: ;
					}
				}
				LA14_: ;
			}
			nl__pureZjson_4347(result, ml);
			indent__pureZjson_4339(result, currIndent);
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_18));
		}
		goto LA6_;
		LA9_: ;
		{
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_38));
		}
		LA6_: ;
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4):
	{
		{
			if (!lstArr) goto LA33_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA33_: ;
		toUgly__pureZjson_4381(result, node);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2):
	{
		{
			if (!lstArr) goto LA38_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA38_: ;
		addInt__stdZprivateZdigitsutils_167(result, (*node)._kind_2.num);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 3):
	{
		{
			if (!lstArr) goto LA43_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA43_: ;
		addFloat__system_3130(result, (*node)._kind_3.fnum);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1):
	{
		NimStringDesc* T50_;
		{
			if (!lstArr) goto LA48_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA48_: ;
		T50_ = NIM_NIL;
		{
			if (!(*node)._kind_4.bval) goto LA53_;
			T50_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_19));
		}
		goto LA51_;
		LA53_: ;
		{
			T50_ = copyString(((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_20));
		}
		LA51_: ;
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), (T50_ ? T50_->Sup.len : 0) + 0));
appendString((*result), T50_);
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 6):
	{
		{
			if (!lstArr) goto LA59_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA59_: ;
		{
			NI T63_;
			T63_ = ((*node)._kind_7.elems ? (*node)._kind_7.elems->Sup.len : 0);
			if (!!((T63_ == ((NI) 0)))) goto LA64_;
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_13));
			nl__pureZjson_4347(result, ml);
			{
				NI i_2;
				NI colontmp__2;
				NI T67_;
				NI res;
				i_2 = (NI)0;
				colontmp__2 = (NI)0;
				T67_ = ((*node)._kind_7.elems ? (*node)._kind_7.elems->Sup.len : 0);
				colontmp__2 = (NI)(T67_ - ((NI) 1));
				res = ((NI) 0);
				{
					while (1) {
						NI T74_;
						if (!(res <= colontmp__2)) goto LA69;
						i_2 = res;
						{
							if (!(((NI) 0) < i_2)) goto LA72_;
							unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_14));
							nl__pureZjson_4347(result, ml);
						}
						LA72_: ;
						T74_ = (NI)0;
						T74_ = newIndent__pureZjson_4342(currIndent, indent, ml);
						toPretty__pureZjson_4399(result, (*node)._kind_7.elems->data[i_2], indent, ml, NIM_TRUE, T74_);
						res += ((NI) 1);
					} LA69: ;
				}
			}
			nl__pureZjson_4347(result, ml);
			indent__pureZjson_4339(result, currIndent);
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 1));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_15));
		}
		goto LA61_;
		LA64_: ;
		{
			unsureAsgnRef((void**) (&(*result)), resizeString((*result), 2));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_39));
		}
		LA61_: ;
	}
	break;
	case ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 0):
	{
		{
			if (!lstArr) goto LA79_;
			indent__pureZjson_4339(result, currIndent);
		}
		LA79_: ;
		unsureAsgnRef((void**) (&(*result)), resizeString((*result), 4));
appendString((*result), ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_21));
	}
	break;
	}
}
N_LIB_PRIVATE N_NIMCALL(NimStringDesc*, pretty__pureZjson_4480)(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* node, NI indent) {
	NimStringDesc* result;
	result = NIM_NIL;
	result = ((NimStringDesc*) NIM_NIL);
	toPretty__pureZjson_4399((&result), node, indent, NIM_TRUE, NIM_FALSE, ((NI) 0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1809)(NimStringDesc* s) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	NimStringDesc* T2_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 4);
	T2_ = NIM_NIL;
	T2_ = (*T1_)._kind_1.str; (*T1_)._kind_1.str = copyStringRC1(s);
	if (T2_) nimGCunrefNoCycle(T2_);
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1835)(NIM_BOOL b) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 1);
	(*T1_)._kind_4.bval = b;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1819)(NI n) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	result = NIM_NIL;
	T1_ = NIM_NIL;
	T1_ = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*) newObj((&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_), sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g));
	(*T1_).kind = ((tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A) 2);
	(*T1_)._kind_2.num = ((NI64) (n));
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___jsgen_6815)(NimStringDesc** elements, NI elementsLen_0) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	result = NIM_NIL;
	result = newJArray__pureZjson_133();
	{
		NimStringDesc** elem;
		NI i;
		elem = (NimStringDesc**)0;
		i = ((NI) 0);
		{
			while (1) {
				tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T4_;
				if (!(i < elementsLen_0)) goto LA3;
				elem = (&elements[i]);
				T4_ = NIM_NIL;
				T4_ = percent___pureZjson_1809((*elem));
				add__pureZjson_241(result, T4_);
				i += ((NI) 1);
			} LA3: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___jsgen_6808)(tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw o) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T1_;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T2_;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T3_;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T4_;
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T5_;
	result = NIM_NIL;
	result = newJObject__pureZjson_102();
	T1_ = NIM_NIL;
	T1_ = percent___pureZjson_1819(o.version);
	X5BX5Deq___pureZjson_1942(result, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_40), T1_);
	T2_ = NIM_NIL;
	T2_ = percent___jsgen_6815((o.sources) ? (o.sources->data) : NIM_NIL, (o.sources ? o.sources->Sup.len : 0));
	X5BX5Deq___pureZjson_1942(result, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_41), T2_);
	T3_ = NIM_NIL;
	T3_ = percent___jsgen_6815((o.names) ? (o.names->data) : NIM_NIL, (o.names ? o.names->Sup.len : 0));
	X5BX5Deq___pureZjson_1942(result, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_42), T3_);
	T4_ = NIM_NIL;
	T4_ = percent___pureZjson_1809(o.mappings);
	X5BX5Deq___pureZjson_1942(result, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_43), T4_);
	T5_ = NIM_NIL;
	T5_ = percent___pureZjson_1809(o.file);
	X5BX5Deq___pureZjson_1942(result, ((NimStringDesc*) &TM__9b9bytt1stv9cZ8uqII7HFgew_44), T5_);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___jsgen_6801)(tyObject_SourceMapcolonObjectType___89bcT7tAiSyU9c6yCaBjaTTw* o) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	result = NIM_NIL;
	{
		if (!(o == 0)) goto LA3_;
		result = newJNull__pureZjson_100();
	}
	goto LA1_;
	LA3_: ;
	{
		result = percent___jsgen_6808((*o));
	}
	LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___docgen_5835)(tyObject_Table__IARuioJxsgUIwpXiUkOgKg table) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
	result = NIM_NIL;
	result = newJObject__pureZjson_102();
	{
		NimStringDesc* k;
		NimStringDesc* v;
		NI L;
		k = NIM_NIL;
		v = NIM_NIL;
		L = len__docgen_5888(table);
		{
			NI h;
			NI colontmp_;
			NI T3_;
			NI res;
			h = (NI)0;
			colontmp_ = (NI)0;
			T3_ = ((table.data ? table.data->Sup.len : 0)-1);
			colontmp_ = T3_;
			res = ((NI) 0);
			{
				while (1) {
					if (!(res <= colontmp_)) goto LA5;
					h = res;
					{
						NIM_BOOL T8_;
						tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* T11_;
						T8_ = (NIM_BOOL)0;
						T8_ = isFilled__pureZcollectionsZtables_31(table.data->data[h].Field0);
						if (!T8_) goto LA9_;
						k = table.data->data[h].Field1;
						v = table.data->data[h].Field2;
						T11_ = NIM_NIL;
						T11_ = percent___pureZjson_1809(v);
						X5BX5Deq___pureZjson_1942(result, k, T11_);
					}
					LA9_: ;
					res += ((NI) 1);
				} LA5: ;
			}
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*, percent___pureZjson_1838)(tyTuple__Qs8sDfUhU9bpCSJUdwfMJiA* keyVals, NI keyValsLen_0) {
	tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g* result;
{	result = NIM_NIL;
	{
		if (!(keyValsLen_0 == ((NI) 0))) goto LA3_;
		result = newJArray__pureZjson_133();
		goto BeforeRet_;
	}
	LA3_: ;
	result = newJObject__pureZjson_102();
	{
		NimStringDesc** key;
		tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g** val;
		NI i;
		key = (NimStringDesc**)0;
		val = (tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g**)0;
		i = ((NI) 0);
		{
			while (1) {
				if (!(i < keyValsLen_0)) goto LA7;
				key = (&keyVals[i].Field0);
				val = &keyVals[i].Field1;
				X5BX5Deq___pureZjson_306((&(*result)._kind_6.fields), (*key), (*val));
				i += ((NI) 1);
			} LA7: ;
		}
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, atmdotdotatslibatspureatsjsondotnim_DatInit000)(void) {
static TNimNode* TM__9b9bytt1stv9cZ8uqII7HFgew_22_7[7];
NI TM__9b9bytt1stv9cZ8uqII7HFgew_24;
static char* NIM_CONST TM__9b9bytt1stv9cZ8uqII7HFgew_23[7] = {
"JNull", 
"JBool", 
"JInt", 
"JFloat", 
"JString", 
"JObject", 
"JArray"};
static TNimNode* TM__9b9bytt1stv9cZ8uqII7HFgew_27_2[2];
static TNimNode* TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[4];
static TNimNode* TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[4];
static TNimNode TM__9b9bytt1stv9cZ8uqII7HFgew_0[28];
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.size = sizeof(tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A);
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.align = NIM_ALIGNOF(tyEnum_JsonNodeKind__SME9c3kTLtQAHAI8HiX0v8A);
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.kind = 14;
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.base = 0;
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.flags = 3;
for (TM__9b9bytt1stv9cZ8uqII7HFgew_24 = 0; TM__9b9bytt1stv9cZ8uqII7HFgew_24 < 7; TM__9b9bytt1stv9cZ8uqII7HFgew_24++) {
TM__9b9bytt1stv9cZ8uqII7HFgew_0[TM__9b9bytt1stv9cZ8uqII7HFgew_24+0].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[TM__9b9bytt1stv9cZ8uqII7HFgew_24+0].offset = TM__9b9bytt1stv9cZ8uqII7HFgew_24;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[TM__9b9bytt1stv9cZ8uqII7HFgew_24+0].name = TM__9b9bytt1stv9cZ8uqII7HFgew_23[TM__9b9bytt1stv9cZ8uqII7HFgew_24];
TM__9b9bytt1stv9cZ8uqII7HFgew_22_7[TM__9b9bytt1stv9cZ8uqII7HFgew_24] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[TM__9b9bytt1stv9cZ8uqII7HFgew_24+0];
}
TM__9b9bytt1stv9cZ8uqII7HFgew_0[7].len = 7; TM__9b9bytt1stv9cZ8uqII7HFgew_0[7].kind = 2; TM__9b9bytt1stv9cZ8uqII7HFgew_0[7].sons = &TM__9b9bytt1stv9cZ8uqII7HFgew_22_7[0];
NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_.node = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[7];
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.size = sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g);
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.align = NIM_ALIGNOF(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g);
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.kind = 18;
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.base = 0;
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.flags = 2;
TM__9b9bytt1stv9cZ8uqII7HFgew_27_2[0] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[9];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[9].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[9].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, isUnquoted);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[9].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[9].name = "isUnquoted";
TM__9b9bytt1stv9cZ8uqII7HFgew_27_2[1] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[10];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].kind = 3;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, kind);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].typ = (&NTIjsonnodekind__SME9c3kTLtQAHAI8HiX0v8A_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].name = "kind";
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].sons = &NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[0];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[10].len = 7;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[11].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[11].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_1.str);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[11].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[11].name = "str";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[4] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[11];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[12].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[12].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_2.num);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[12].typ = (&NTIbiggestint__Aav8dQoMlCFnZRxA0IhTHQ_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[12].name = "num";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[2] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[12];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[13].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[13].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_3.fnum);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[13].typ = (&NTIfloat__w9bl9a1ul9ctRJWiMl9cNnIMvg_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[13].name = "fnum";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[3] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[13];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[14].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[14].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_4.bval);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[14].typ = (&NTIbool__VaVACK0bpYmqIQ0mKcHfQQ_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[14].name = "bval";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[1] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[14];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[15].len = 0; TM__9b9bytt1stv9cZ8uqII7HFgew_0[15].kind = 2;
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[0] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[15];
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.size = sizeof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ);
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.align = NIM_ALIGNOF(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ);
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.kind = 18;
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.base = 0;
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.flags = 2;
TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[0] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[18];
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.size = sizeof(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ);
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.align = NIM_ALIGNOF(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ);
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.kind = 18;
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.base = 0;
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.flags = 2;
TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[0] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[20];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[20].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[20].offset = offsetof(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ, Field0);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[20].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[20].name = "Field0";
TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[1] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[21];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[21].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[21].offset = offsetof(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ, Field1);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[21].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[21].name = "Field1";
TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[2] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[22];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[22].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[22].offset = offsetof(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ, Field2);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[22].typ = (&NTIstring__77mFvmsOLKik79ci2hXkHEg_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[22].name = "Field2";
TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[3] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[23];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[23].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[23].offset = offsetof(tyTuple__CWLiqluAXi3Y4RHZUwBh9bQ, Field3);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[23].typ = (&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[23].name = "Field3";
TM__9b9bytt1stv9cZ8uqII7HFgew_0[19].len = 4; TM__9b9bytt1stv9cZ8uqII7HFgew_0[19].kind = 2; TM__9b9bytt1stv9cZ8uqII7HFgew_0[19].sons = &TM__9b9bytt1stv9cZ8uqII7HFgew_29_4[0];
NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_.node = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[19];
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.size = sizeof(tySequence__CZrkID0OnHjQpN63AqYJwg*);
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.align = NIM_ALIGNOF(tySequence__CZrkID0OnHjQpN63AqYJwg*);
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.kind = 24;
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.base = (&NTIorderedkeyvaluepair__CWLiqluAXi3Y4RHZUwBh9bQ_);
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.flags = 2;
NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_.marker = Marker_tySequence__CZrkID0OnHjQpN63AqYJwg;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[18].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[18].offset = offsetof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ, data);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[18].typ = (&NTIorderedkeyvaluepairseq__CZrkID0OnHjQpN63AqYJwg_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[18].name = "data";
TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[1] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[24];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[24].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[24].offset = offsetof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ, counter);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[24].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[24].name = "counter";
TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[2] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[25];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[25].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[25].offset = offsetof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ, first);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[25].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[25].name = "first";
TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[3] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[26];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[26].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[26].offset = offsetof(tyObject_OrderedTable__S0a9amCISWbmv4PR18G6gmQ, last);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[26].typ = (&NTIint__rR5Bzr1D5krxoo1NcNyeMA_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[26].name = "last";
TM__9b9bytt1stv9cZ8uqII7HFgew_0[17].len = 4; TM__9b9bytt1stv9cZ8uqII7HFgew_0[17].kind = 2; TM__9b9bytt1stv9cZ8uqII7HFgew_0[17].sons = &TM__9b9bytt1stv9cZ8uqII7HFgew_28_4[0];
NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_.node = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[17];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[16].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[16].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_6.fields);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[16].typ = (&NTIorderedtable__S0a9amCISWbmv4PR18G6gmQ_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[16].name = "fields";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[5] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[16];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[27].kind = 1;
TM__9b9bytt1stv9cZ8uqII7HFgew_0[27].offset = offsetof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g, _kind_7.elems);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[27].typ = (&NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_);
TM__9b9bytt1stv9cZ8uqII7HFgew_0[27].name = "elems";
NimDT___wYd81YPSGeV9aTaTIRihe3g_kind[6] = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[27];
TM__9b9bytt1stv9cZ8uqII7HFgew_0[8].len = 2; TM__9b9bytt1stv9cZ8uqII7HFgew_0[8].kind = 2; TM__9b9bytt1stv9cZ8uqII7HFgew_0[8].sons = &TM__9b9bytt1stv9cZ8uqII7HFgew_27_2[0];
NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_.node = &TM__9b9bytt1stv9cZ8uqII7HFgew_0[8];
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.size = sizeof(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*);
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.align = NIM_ALIGNOF(tyObject_JsonNodeObj__wYd81YPSGeV9aTaTIRihe3g*);
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.kind = 22;
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.base = (&NTIjsonnodeobj__wYd81YPSGeV9aTaTIRihe3g_);
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.flags = 2;
NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_.marker = Marker_tyRef__LaYTJJQFT9b3qbn9c5fIsCog;
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.size = sizeof(tySequence__qIo1GWQhO9cOgsAJDKUY8kw*);
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.align = NIM_ALIGNOF(tySequence__qIo1GWQhO9cOgsAJDKUY8kw*);
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.kind = 24;
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.base = (&NTIjsonnode__LaYTJJQFT9b3qbn9c5fIsCog_);
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.flags = 2;
NTIseqLjsonnodeT__qIo1GWQhO9cOgsAJDKUY8kw_.marker = Marker_tySequence__qIo1GWQhO9cOgsAJDKUY8kw;
}

